@@ -172,9 +172,9 @@ def discover_changed_files(repo):
 
     repo = local_repo()
     changed = repo.git.diff('--name-status', 'master').split('\n')
-    result = [l.split('\t', 1) for l in changed]
+    result = [l.split('\t', 1) for l in changed if l]
 
-    return [f[1] for f in result if f and f[0] != 'D']
+    return [f[1] for f in result if f[0] != 'D']
 
 
 def pylint_pre_push(*args, **kwd):
